# PyUtils helperBy

A collection of useful Python utilities for console applications, system monitoring, and progress tracking.


## Use

```bash
import helperBy

helperBy.calculate(1/2,1,2) # if 1 its print to value of 2 numbers, if 2 to value and arithmetic mean, next lines its unlimited values

```


## Installation

```bash
pip install helperBy
```
